lavalink_rs.model.http API documentation

# lavalink_rs.model.http

class UpdatePlayer:

Updates or creates the player for this guild.

If every field is None, the player will stop playing.

volume

The player volume.

In percentage, from 0 to 1000.

end_time

The track end time in milliseconds.

It must be a value above 0 or None.

None resets this if it was set previously.

position

The track position in milliseconds.

This value can be set to start a track at a specific time.

track

The track to play.

paused

Whether the player should be paused.

filters

The filters to apply.

This will override all previously applied filters.

voice

The discord websocket connection information.

Required for creating a player.

class UpdatePlayerTrack:
encoded
identifier
user_data
class ResumingState:

Updates the session with the resuming state and timeout.

You must call this method if you wish to restart the discord bot without having all players stop, and provide the current `session_id` when creating the node connection.

resuming

Whether resuming should be, or is enabled for this session or not.

timeout

The timeout in seconds.

default is 60s

class Info:

Information about the Lavalink node.

version

The semver version of the Lavalink server.

lavaplayer

The Lavaplayer version being used by the Lavalink server.

plugins

The enabled plugins for the Lavalink server.

git

The git information of the Lavalink server.

filters

The enabled filters for the Lavalink server.

build_time

The millisecond unix timestamp when the Lavalink jar was built.

source_managers

The enabled source managers for the Lavalink server.

jvm

The JVM version the Lavalink server is running on.

class Git:
commit

The commit the Lavalink server was built on.

commit_time

The millisecond unix timestamp for when the commit was created.

branch

The branch the Lavalink server was built on.

class Plugin:
name

The name of the plugin

version

The version of the plugin

class Version:

Check out Semantic Versioning 2.0.0 to know what these fields mean.

minor
major
patch
semver
pre_release
build